.. _bblean-publications:

.. currentmodule:: bblean

Publications
============

If you find this software useful please cite the following articles:

- *BitBIRCH: efficient clustering of large molecular libraries*:
    https://doi.org/10.1039/D5DD00030K
- *BitBIRCH Clustering Refinement Strategies*:
    https://doi.org/10.1021/acs.jcim.5c00627
- *BitBIRCH-Lean*:
    (preprint) https://www.biorxiv.org/content/10.1101/2025.10.22.684015v1

BitBIRCH-Lean relies on the ``iSIM`` "instant average similarity" framework. The
relevant iSIM publications are:

- *iSIM: instant similarity*
    https://pubs.rsc.org/en/content/articlelanding/2024/dd/d4dd00041b
- *Extended similarity indices: Part I*
    https://doi.org/10.1186/s13321-021-00505-3
- *Extended similarity indices: Part II*
    https://doi.org/10.1186/s13321-021-00504-4

The *BIRCH* algorithm was originally proposed in 1997 by Zhang et al. in *BIRCH: A new
data clustering algorithm and its applications* https://doi.org/10.1023/A:1009783824328.
